@@ -3,15 +3,19 @@ from scipy.stats import rv_discrete
 
 
 class ConPov:
-    '''
-    :param a: is a list and sum of all elements should be equal to 1
-    :param n: is a integer value
-    '''
+
     def __init__(self,a,n):
+        '''
+        :param a: is a list and sum of all elements should be equal to 1
+        :param n: is a integer value
+        '''
         self.series = a
         self.single_value = n
 
     def conpov(self):
+        '''
+        :return: Self convolution of discrete distribution
+        '''
         n1 = self.single_value
         basis = [self.single_value]
         while n1 > 1:
@@ -33,6 +37,4 @@ class ConPov:
         return custm.pmf(x)
 
 
-custm = ConPov([0.5,0.5],2000).conpov()
-print(custm)
 
